/* BDF - Copyright (c) 2018-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.jsonproducers;

import fr.exemole.bdfserver.multi.Multi;
import java.io.IOException;
import net.mapeadores.util.json.CommonJson;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.CommandMessage;


/**
 *
 * @author Vincent Calame
 */
public abstract class MultiJsonProducer implements JsonProducer {

    protected final Multi multi;
    protected final MessageLocalisation messageLocalisation;
    protected final Lang lang;
    private final boolean authentified;
    private CommandMessage commandMessage;

    public MultiJsonProducer(Multi multi, boolean authentified) {
        this.multi = multi;
        this.messageLocalisation = multi.getMultiConf().getMessageLocalisation();
        this.lang = multi.getMultiConf().getLang();
        this.authentified = authentified;
    }

    public MultiJsonProducer setCommandMessage(CommandMessage commandMessage) {
        this.commandMessage = commandMessage;
        return this;
    }

    @Override
    public void writeJson(Appendable appendable) throws IOException {
        JSONWriter jsonWriter = new JSONWriter(appendable);
        jsonWriter.object();
        {
            jsonWriter.key("authentified")
                    .value(authentified);
            mainProperties(jsonWriter);
            if (commandMessage != null) {
                jsonWriter.key("commandMessage");
                CommonJson.object(jsonWriter, commandMessage, messageLocalisation);
            }
        }
        jsonWriter.endObject();
    }

    public abstract void mainProperties(JSONWriter jsonWriter) throws IOException;

}
