/* BdfServer - Copyright (c) 2014-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.impl;

import fr.exemole.bdfserver.api.managers.L10nManager;
import fr.exemole.bdfserver.api.storage.ResourceStorage;
import fr.exemole.bdfserver.tools.BdfMessageLocalisationFactory;
import java.util.List;
import net.mapeadores.util.localisation.CodeCatalog;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.LangPreference;
import net.mapeadores.util.localisation.MessageLocalisation;


/**
 *
 * @author Vincent Calame
 */
class L10nManagerImpl implements L10nManager {

    private final List<ResourceStorage> resourceStorageList;
    private BdfMessageLocalisationFactory messageLocalisationFactory;

    L10nManagerImpl(List<ResourceStorage> resourceStorageList) {
        this.resourceStorageList = resourceStorageList;
        innerUpdateMessageLocalisationFactory();
    }

    @Override
    public MessageLocalisation getMessageLocalisation(LangPreference langPreference) {
        return messageLocalisationFactory.newInstance(langPreference);
    }

    @Override
    public MessageLocalisation getMessageLocalisation(Lang lang) {
        return messageLocalisationFactory.newInstance(lang);
    }

    @Override
    public void update() {
        innerUpdateMessageLocalisationFactory();
    }

    @Override
    public CodeCatalog getCodeCatalog() {
        return messageLocalisationFactory;
    }

    private void innerUpdateMessageLocalisationFactory() {
        this.messageLocalisationFactory = BdfMessageLocalisationFactory.buildFactory(resourceStorageList);
    }

}
