/* BdfServer_Commands - Copyright (c) 2015-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.util.ArrayList;
import java.util.List;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ExtensionActivationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "ExtensionActivation";
    public final static String COMMANDKEY = "_ CNF-18";
    public final static String ACTIVATION_PARAMNAME = "activation";
    private List<String> activeExtensionList;

    public ExtensionActivationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        bdfServerEditor.setActiveExtensionList(activeExtensionList);
        bdfServerEditor.saveChanges();
        setDone("_ done.configuration.extensionactivation");
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        String[] values = requestMap.getParameterValues(ACTIVATION_PARAMNAME);
        activeExtensionList = new ArrayList<String>();
        if (values != null) {
            for (String value : values) {
                value = value.trim();
                if (value.length() > 0) {
                    activeExtensionList.add(value);
                }
            }
        }
        return true;
    }

}
