/* BdfServer_Commands - Copyright (c) 2010-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.metadata.FichothequeMetadataEditor;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class IdentificationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "Identification";
    public final static String COMMANDKEY = "_ CNF-01";
    public final static String AUTHORITY_PARAMNAME = "authority";
    public final static String BASENAME_PARAMNAME = "basename";
    private String baseName;
    private String authority;

    public IdentificationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.CONFIGURATION + "/" + COMMANDNAME);
        FichothequeMetadataEditor fichothequeMetadataEditor = editSession.getFichothequeEditor().getFichothequeMetadataEditor();
        boolean done1 = fichothequeMetadataEditor.setAuthority(authority);
        boolean done2 = fichothequeMetadataEditor.setBaseName(baseName);
        if ((done1) || (done2)) {
            setDone("_ done.configuration.identification");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        baseName = getMandatory(BASENAME_PARAMNAME);
        authority = getMandatory(AUTHORITY_PARAMNAME);
        if (!StringUtils.isTechnicalName(baseName, true)) {
            addMultiError("_ error.wrong.basename_fichotheque", baseName);
        }
        if (!StringUtils.isAuthority(authority)) {
            addMultiError("_ error.wrong.authority", authority);
        }
        if (hasMultiError()) {
            setMultiErrorTitle("_ error.list.configuration");
            return false;
        }
        return true;
    }

}
