/* BdfServer_HtmlProducers - Copyright (c) 2012-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.ConfigurationDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.tools.instruction.PermissionChecker;
import net.mapeadores.util.html.HtmlProducer;


/**
 *
 * @author Vincent Calame
 */
public final class ConfigurationHtmlProducerFactory {

    private ConfigurationHtmlProducerFactory() {
    }

    public static HtmlProducer getHtmlProducer(OutputParameters parameters) throws BdfInstructionException {
        BdfServerHtmlProducer htmlProducer = getBdfHtmlProducer(parameters);
        if (htmlProducer != null) {
            htmlProducer.setBdfCommandResult(parameters.getBdfCommandResult());
        }
        return htmlProducer;
    }

    private static BdfServerHtmlProducer getBdfHtmlProducer(OutputParameters parameters) throws BdfInstructionException {
        String page = parameters.getOutput();
        BdfServer bdfServer = parameters.getBdfServer();
        BdfUser bdfUser = parameters.getBdfUser();
        PermissionChecker checker = new PermissionChecker(bdfServer, bdfUser);
        checker.checkGlobalAdmin();
        switch (page) {
            case ConfigurationDomain.COREFORM_PAGE: {
                return new CoreFormHtmlProducer(checker);
            }
            case ConfigurationDomain.PHRASESFORM_PAGE: {
                return new PhrasesFormHtmlProducer(checker);
            }
            case ConfigurationDomain.LOGOSFORM_PAGE: {
                return new LogosFormHtmlProducer(checker);
            }
            case ConfigurationDomain.SUBSETTREEFORM_PAGE: {
                return new SubsetTreeFormHtmlProducer(checker);
            }
            case ConfigurationDomain.ETCCONFIG_PAGE: {
                return new EtcConfigHtmlProducer(checker);
            }
            case ConfigurationDomain.EXTENSIONSFORM_PAGE: {
                return new ExtensionsFormHtmlProducer(checker);
            }
            case ConfigurationDomain.CONFIGADVANCEDCOMMANDS_PAGE: {
                return new ConfigurationAdvancedCommandsHtmlProducer(checker);
            }
            case ConfigurationDomain.GROUPFORM_PAGE: {
                return new GroupFormHtmlProducer(checker);
            }
            default:
                return null;
        }
    }

}
