/* BdfServer_HtmlProducers - Copyright (c) 2012-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.ThesaurusDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfHtmlUtils;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.thesaurus.Thesaurus;
import net.mapeadores.util.html.CommandBox;


/**
 *
 * @author Vincent Calame
 */
public class MotcleCreationFormHtmlProducer extends BdfServerHtmlProducer {

    private final PermissionSummary permissionSummary;
    private final Thesaurus thesaurus;
    private final Motcle parentMotcle;

    public MotcleCreationFormHtmlProducer(ProducerParameters producerParameters, Thesaurus thesaurus, Motcle parentMotcle) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), producerParameters.getPermissionSummary(), thesaurus, parentMotcle);
    }

    public MotcleCreationFormHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, PermissionSummary permissionSummary, Thesaurus thesaurus, Motcle parentMotcle) {
        super(bdfServer, bdfUser);
        addJsLib(CommonJsLibs.COMMANDTEST);
        addThemeCss("thesaurus.css");
        this.permissionSummary = permissionSummary;
        this.thesaurus = thesaurus;
        this.parentMotcle = parentMotcle;
    }

    @Override
    public void printHtml() {
        start();
        BdfHtmlUtils.printSubsetHeader(this, bdfServer, bdfUser, permissionSummary, thesaurus, ThesaurusDomain.MOTCLE_CREATIONFORM_PAGE);
        printCommandMessageUnit();
        CommandBox commandBox = CommandBox.init()
                .action(Domains.THESAURUS)
                .family("THS")
                .page(ThesaurusDomain.MOTCLE_CHANGEFORM_PAGE)
                .errorPage(ThesaurusDomain.MOTCLE_CREATIONFORM_PAGE);
        ThesaurusCommandBoxUtils.printMotcleCreationBox(this, commandBox, thesaurus, parentMotcle, bdfServer, workingLang);
        end();
    }

}
