/* BdfServer_JsonProducers - Copyright (c) 2013-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.addenda;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.AddendaDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.instruction.PermissionChecker;
import net.fichotheque.addenda.Addenda;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public final class AddendaJsonProducerFactory {

    private AddendaJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws BdfInstructionException {
        String json = parameters.getOutput();
        BdfServer bdfServer = parameters.getBdfServer();
        BdfUser bdfUser = parameters.getBdfUser();
        RequestMap requestMap = parameters.getRequestMap();
        PermissionChecker checker = new PermissionChecker(bdfServer, bdfUser);
        Addenda addenda = BdfInstructionUtils.getMandatoryAddenda(bdfServer.getFichotheque(), requestMap);
        checker.checkSubsetAccess(addenda);
        switch (json) {
            case AddendaDomain.DOCUMENT_ARRAY_JSON: {
                return new DocumentArrayJsonProducer(checker, addenda);
            }
            default:
                return null;
        }
    }

}
