/* FichothequeLib_API - Copyright (c) 2013-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.corpus.fiche;

import java.util.List;
import net.fichotheque.corpus.metadata.FieldKey;
import net.mapeadores.util.localisation.Lang;


/**
 * Interface définissant le contenu d'une fiche.
 *
 * @author Vincent Calame
 */
public interface FicheAPI {

    /**
     * Retourne le titre de la fiche. La valeur n'est jamais nulle mais peut
     * être vide
     *
     * @return le titre de la fiche
     */
    public String getTitre();

    /**
     * Retourne la langue de la fiche. Peut être nul.
     * <p>
     * La langue d'une fiche est unique. Lorsqu'une fiche est multilingue, elle
     * aura comme valeur de langue <tt>mul</tt>.
     *
     * @return la langue de la fiche
     */
    public Lang getLang();


    /**
     * Retourne le sous-titre de la fiche. Peut être nul.
     * <p>
     * Le champ Sous-titre est le seul champ spécial quui est optionnel (i.e.
     * certains corpus ne l'utilisent pas).
     *
     * @return le sous-titre de la fiche.
     */
    public Para getSoustitre();

    /**
     * Retourne la liste des rédacteurs de la fiche. Est nul ou de longueur non
     * nulle.
     * <p>
     * La liste des rédacteurs sert notamment à déterminer les droits sur la
     * fiche.
     *
     * @return la liste des rédacteurs
     */

    public FicheItems getRedacteurs();

    public List<Propriete> getProprieteList();

    public List<Information> getInformationList();

    public List<Section> getSectionList();

    /**
     * Retourne la propriété correspondant au champ en argument. Peut être nul
     * si la propriété n'existe pas et renvoie une exception si fieldKey n'est
     * pas la clé d'un champ de type Propriete.
     *
     * @param fieldKey clé du champ propriété
     * @return instance de Propriete correspondante ou nul
     */
    public Propriete getPropriete(FieldKey fieldKey);


    /**
     * Retourne l'information correspondant au champ en argument. Peut être nul
     * si l'information n'existe pas et renvoie une exception si fieldKey n'est
     * pas la clé d'un champ de type Information.
     *
     * @param fieldKey clé du champ information
     * @return instance de Information correspondante ou nul
     */
    public Information getInformation(FieldKey fieldKey);

    /**
     * Retourne la section correspondant au champ en argument. Peut être nul si
     * la section n'existe pas et renvoie une exception si fieldKey n'est pas la
     * clé d'un champ de type Section.
     *
     * @param fieldKey clé du champ section
     * @return instance de Section correspondante ou nul
     */
    public Section getSection(FieldKey fieldKey);

}
