/* FichothequeLib_Tools - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.dom;

import java.text.ParseException;
import net.fichotheque.FichothequeEditor;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeBuilder;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.attr.CheckedNameSpace;
import net.mapeadores.util.attr.CheckedLocalKey;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.text.CleanedString;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import net.mapeadores.util.xml.XMLUtils;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class AttributeDOMReader {

    private final FichothequeEditor fichothequeEditor;
    private final MessageHandler messageHandler;

    public AttributeDOMReader(FichothequeEditor fichothequeEditor, MessageHandler messageHandler) {
        this.fichothequeEditor = fichothequeEditor;
        this.messageHandler = messageHandler;
    }

    public void readAttrElement(Element element, Object attributeHolder, String xpath) {
        String nameSpaceString = element.getAttribute("ns");
        if (nameSpaceString.length() == 0) {
            DomMessages.emptyAttribute(messageHandler, xpath, "ns");
            return;
        }
        String localKeyString = element.getAttribute("key");
        if (localKeyString.length() == 0) {
            DomMessages.emptyAttribute(messageHandler, xpath, "key");
            return;
        }
        xpath = xpath + "[@ns='" + nameSpaceString + "' AND @key='" + localKeyString + "']";
        CheckedNameSpace nameSpace;
        try {
            nameSpace = CheckedNameSpace.parse(nameSpaceString);
        } catch (ParseException pe) {
            DomMessages.wrongAttributeValue(messageHandler, xpath, "ns", nameSpaceString);
            return;
        }
        CheckedLocalKey localKey;
        try {
            localKey = CheckedLocalKey.parse(localKeyString);
        } catch (ParseException pe) {
            DomMessages.wrongAttributeValue(messageHandler, xpath, "key", localKeyString);
            return;
        }
        AttributeKey attributeKey = AttributeKey.build(nameSpace, localKey);
        AttributeHandler attributeHandler = new AttributeHandler(attributeKey);
        DOMUtils.readChildren(element, attributeHandler);
        Attribute attribute = attributeHandler.toAttribute();
        if (attribute != null) {
            fichothequeEditor.putAttribute(attributeHolder, attribute);
        }
    }


    private class AttributeHandler implements ElementHandler {

        private final AttributeBuilder attributeBuilder;

        private AttributeHandler(AttributeKey attributeKey) {
            this.attributeBuilder = new AttributeBuilder(attributeKey);
        }

        private Attribute toAttribute() {
            return attributeBuilder.toAttribute();
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("val")) {
                CleanedString cs = XMLUtils.toCleanedString(element);
                if (cs != null) {
                    attributeBuilder.addValue(cs);
                } else {
                    DomMessages.emptyElement(messageHandler, "val");
                }
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
