/* FichothequeLib_Tools - Copyright (c) 2013-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.dom;

import java.text.ParseException;
import net.fichotheque.ExistingNameException;
import net.fichotheque.FichothequeConstants;
import net.fichotheque.addenda.AddendaEditor;
import net.fichotheque.addenda.Document;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class DocumentDOMReader {

    private final MessageHandler messageHandler;
    private final AddendaEditor addendaEditor;
    private final AttributeDOMReader attributeDOMReader;
    private final RootHandler rootHandler = new RootHandler();

    public DocumentDOMReader(AddendaEditor addendaEditor, MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
        this.addendaEditor = addendaEditor;
        this.attributeDOMReader = new AttributeDOMReader(addendaEditor.getFichothequeEditor(), messageHandler);
    }

    public void fillDocument(Document document, Element element) {
        String basename = element.getAttribute("basename");
        if (basename.length() > 0) {
            try {
                addendaEditor.setBasename(document, basename);
            } catch (ExistingNameException ebe) {
                messageHandler.addMessage(FichothequeConstants.SEVERE_FICHOTHEQUE, "_ error.existing.documentname", basename);
            } catch (ParseException pe) {
                DomMessages.wrongAttributeValue(messageHandler, element.getTagName(), "basename", basename);
            }
        }
        rootHandler.setDocument(document);
        DOMUtils.readChildren(element, rootHandler);
    }


    private class RootHandler implements ElementHandler {

        private Document document;

        private RootHandler() {
        }

        private void setDocument(Document document) {
            this.document = document;
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("attr")) {
                attributeDOMReader.readAttrElement(element, document, tagName);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
