/* FichothequeLib_Tools - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.Collections;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.ExtraitThesaurusDef;
import net.fichotheque.extraction.def.MotcleFilter;
import net.fichotheque.utils.SelectionUtils;
import net.fichotheque.selection.MotcleQuery;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitThesaurusDefBuilder implements ExtractionConstants {

    private MotcleFilter motcleFilter;
    private String extraitName = null;
    private String tagName = EXTRAITTHESAURUS_DEFAULT_TAGNAME;
    private List<MotcleQuery> motcleQueryList = SelectionUtils.EMPTY_MOTCLEQUERYLIST;

    public ExtraitThesaurusDefBuilder(MotcleFilter motcleFilter) {
        if (motcleFilter == null) {
            throw new IllegalArgumentException("motcleFilter is null");
        }
        this.motcleFilter = motcleFilter;
    }


    public ExtraitThesaurusDefBuilder setMotcleFilter(MotcleFilter motcleFilter) {
        if (motcleFilter == null) {
            throw new IllegalArgumentException("motcleFilter is null");
        }
        this.motcleFilter = motcleFilter;
        return this;
    }

    public ExtraitThesaurusDefBuilder setExtraitName(String extraitName) {
        if ((extraitName != null) && (extraitName.length() == 0)) {
            extraitName = null;
        }
        this.extraitName = extraitName;
        return this;
    }

    public ExtraitThesaurusDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, EXTRAITTHESAURUS_DEFAULT_TAGNAME);
        return this;
    }

    public ExtraitThesaurusDefBuilder setMotcleQueryList(List<MotcleQuery> list) {
        this.motcleQueryList = list;
        return this;
    }

    public ExtraitThesaurusDefBuilder setMotcleQueryList(MotcleQuery motcleQuery) {
        this.motcleQueryList = Collections.singletonList(motcleQuery);
        return this;
    }

    public ExtraitThesaurusDef toExtraitThesaurusDef() {
        return new InternalExtraitThesaurusDef(motcleFilter, extraitName, tagName, motcleQueryList);
    }

    public static ExtraitThesaurusDefBuilder init(MotcleFilter motcleFilter) {
        return new ExtraitThesaurusDefBuilder(motcleFilter);
    }


    private static class InternalExtraitThesaurusDef implements ExtraitThesaurusDef {

        private final MotcleFilter motcleFilter;
        private final String extraitName;
        private final String tagName;
        private final List<MotcleQuery> motcleQueryList;

        private InternalExtraitThesaurusDef(MotcleFilter motcleFilter, String extraitName, String tagName, List<MotcleQuery> motcleQueryList) {
            this.motcleFilter = motcleFilter;
            this.extraitName = extraitName;
            this.tagName = tagName;
            this.motcleQueryList = motcleQueryList;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public String getExtraitName() {
            return extraitName;
        }

        @Override
        public MotcleFilter getMotcleFilter() {
            return motcleFilter;
        }

        @Override
        public List<MotcleQuery> getMotcleQueryList() {
            return motcleQueryList;
        }

    }

}
