/* FichothequeLib_Tools - Copyright (c) 2010-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.GroupClause;
import net.fichotheque.extraction.def.GroupParams;
import net.fichotheque.xml.extraction.ExtractionXMLUtils;


/**
 *
 * @author Vincent Calame
 */
public class GroupClauseBuilder {

    private final short groupType;
    private short sortOrder = ExtractionConstants.ASCENDING_SORT;
    private String tagName = ExtractionConstants.GROUP_DEFAULT_TAGNAME;
    private GroupParams groupParams = null;
    private GroupClause subGroupClause = null;

    public GroupClauseBuilder(short groupType) {
        this.groupType = groupType;
    }

    public GroupClauseBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, ExtractionConstants.GROUP_DEFAULT_TAGNAME);
        return this;
    }

    public GroupClauseBuilder setSortOrder(short sortOrder) {
        this.sortOrder = sortOrder;
        return this;
    }

    public GroupClauseBuilder setGroupParams(GroupParams groupParams) {
        this.groupParams = groupParams;
        return this;
    }

    public GroupClauseBuilder setSubGroupClause(GroupClause groupClause) {
        this.subGroupClause = groupClause;
        return this;
    }

    public GroupClause toGroupClause() {
        switch (groupType) {
            case ExtractionConstants.FIELDS_TYPE:
                if (groupParams == null) {
                    throw new IllegalStateException("groupParams is null");
                }
        }
        return new InternalGroupClause(groupType, sortOrder, tagName, groupParams, subGroupClause);
    }

    public static GroupClauseBuilder init(short groupType) {
        return new GroupClauseBuilder(groupType);
    }

    public static GroupClause getGroupClause(String groupClauseString, boolean hidden) {
        int idx = groupClauseString.indexOf('-');
        if (idx == -1) {
            return null;
        }
        String typeString = groupClauseString.substring(0, idx);
        String sortString = groupClauseString.substring(idx + 1);
        short type;
        try {
            type = ExtractionXMLUtils.typeToShort(typeString);

        } catch (IllegalArgumentException iae) {
            return null;
        }
        switch (type) {
            case ExtractionConstants.POIDS_TYPE:
            case ExtractionConstants.TITRE_TYPE:
            case ExtractionConstants.ANNEE_TYPE:
            case ExtractionConstants.LANG_TYPE:
            case ExtractionConstants.POSITION_TYPE:
                break;
            default:
                return null;
        }
        short sort = ExtractionConstants.ASCENDING_SORT;
        try {
            sort = ExtractionXMLUtils.sortToShort(sortString);
        } catch (IllegalArgumentException iae) {
        }
        String tagName = (hidden) ? null : ExtractionConstants.GROUP_DEFAULT_TAGNAME;
        return new InternalGroupClause(type, sort, tagName, null, null);
    }


    private static class InternalGroupClause implements GroupClause {

        private final short groupType;
        private final short sortOrder;
        private final String tagName;
        private final GroupParams groupParams;
        private final GroupClause subGroupClause;

        private InternalGroupClause(short groupType, short sortOrder, String tagName, GroupParams groupParams, GroupClause subGroupClause) {
            this.groupType = groupType;
            this.sortOrder = sortOrder;
            this.tagName = tagName;
            this.groupParams = groupParams;
            this.subGroupClause = subGroupClause;
        }

        @Override
        public short getGroupType() {
            return groupType;
        }

        @Override
        public short getSortOrder() {
            return sortOrder;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public GroupParams getGroupParams() {
            return groupParams;
        }

        @Override
        public GroupClause getSubGroupClause() {
            return subGroupClause;
        }

    }

}
