/* FichothequeLib_Xml - Copyright (c) 2015-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.importation.dom;

import java.text.ParseException;
import net.mapeadores.util.attr.AttributeChangeBuilder;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.attr.CheckedNameSpace;
import net.mapeadores.util.attr.CheckedLocalKey;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.CleanedString;
import net.mapeadores.util.text.LabelChangeBuilder;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.ElementHandler;
import net.mapeadores.util.xml.XMLUtils;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public final class ImportationDomUtils {

    private ImportationDomUtils() {

    }

    public static void readLabelElement(Element element, LabelChangeBuilder changeLabelHolderBuilder) {
        try {
            Lang lang = Lang.parse(element.getAttribute("xml:lang"));
            CleanedString libString = DOMUtils.contentToCleanedString(element);
            if (libString == null) {
                changeLabelHolderBuilder.putRemovedLang(lang);
            } else {
                changeLabelHolderBuilder.putLabel(lang, libString);
            }
        } catch (ParseException pe) {
        }
    }

    public static void readAttrElement(Element element, AttributeChangeBuilder attributeChangeBuilder) {
        String nameSpaceString = element.getAttribute("ns");
        if (nameSpaceString.length() == 0) {
            return;
        }
        String localKeyString = element.getAttribute("key");
        if (localKeyString.length() == 0) {
            return;
        }
        CheckedNameSpace nameSpace;
        try {
            nameSpace = CheckedNameSpace.parse(nameSpaceString);
        } catch (ParseException pe) {
            return;
        }
        CheckedLocalKey localKey;
        try {
            localKey = CheckedLocalKey.parse(localKeyString);
        } catch (ParseException pe) {
            return;
        }
        AttributeKey attributeKey = AttributeKey.build(nameSpace, localKey);
        AttributeHandler attributeHandler = new AttributeHandler(attributeKey, attributeChangeBuilder);
        DOMUtils.readChildren(element, attributeHandler);
        if (!attributeHandler.isDone()) {
            attributeChangeBuilder.putRemovedAttributeKey(attributeKey);
        }
    }


    private static class AttributeHandler implements ElementHandler {

        private final AttributeKey attributeKey;
        private final AttributeChangeBuilder attributeChangeBuilder;
        private boolean done = false;

        private AttributeHandler(AttributeKey attributeKey, AttributeChangeBuilder attributeChangeBuilder) {
            this.attributeKey = attributeKey;
            this.attributeChangeBuilder = attributeChangeBuilder;
        }

        private boolean isDone() {
            return done;
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("val")) {
                CleanedString cs = XMLUtils.toCleanedString(element);
                if (cs != null) {
                    attributeChangeBuilder.appendValue(attributeKey, cs);
                    done = true;
                }
            }
        }

    }


}
