/* FichothequeLib_Tools - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.selection;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import net.fichotheque.SubsetKey;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.selection.CroisementCondition;
import net.fichotheque.selection.DocumentQuery;
import net.fichotheque.utils.FichothequeUtils;


/**
 *
 * @author Vincent Calame
 */
public class DocumentQueryBuilder {

    private final Set<SubsetKey> subsetKeySet = new LinkedHashSet();
    private CroisementCondition croisementCondition;

    public DocumentQueryBuilder() {
    }

    public DocumentQueryBuilder setCroisementCondition(CroisementCondition croisementCondition) {
        this.croisementCondition = croisementCondition;
        return this;
    }

    public DocumentQueryBuilder addAddenda(SubsetKey subsetKey) {
        if (!subsetKey.isAddendaSubset()) {
            throw new IllegalArgumentException("!subsetKey.isAddendaSubset()");
        }
        subsetKeySet.add(subsetKey);
        return this;
    }

    public DocumentQueryBuilder addAddenda(SubsetKey[] subsetKeyArray) {
        for (SubsetKey subsetKey : subsetKeyArray) {
            addAddenda(subsetKey);
        }
        return this;
    }

    public DocumentQueryBuilder addAddenda(Collection<SubsetKey> subsetKeys) {
        for (SubsetKey subsetKey : subsetKeys) {
            addAddenda(subsetKey);
        }
        return this;
    }

    public DocumentQueryBuilder addAddenda(Addenda addenda) {
        subsetKeySet.add(addenda.getSubsetKey());
        return this;
    }

    public DocumentQuery toDocumentQuery() {
        List<SubsetKey> subsetKeyList = FichothequeUtils.wrap(subsetKeySet.toArray(new SubsetKey[subsetKeySet.size()]));
        return new InternalDocumentQuery(subsetKeyList, croisementCondition);
    }

    public static DocumentQueryBuilder init() {
        return new DocumentQueryBuilder();
    }


    private static class InternalDocumentQuery implements DocumentQuery {

        private final List<SubsetKey> addendaKeyList;
        private final CroisementCondition croisementCondition;

        private InternalDocumentQuery(List<SubsetKey> subsetKeyList, CroisementCondition croisementCondition) {
            this.addendaKeyList = subsetKeyList;
            this.croisementCondition = croisementCondition;
        }

        @Override
        public CroisementCondition getCroisementCondition() {
            return croisementCondition;
        }

        @Override
        public List<SubsetKey> getAddendaKeyList() {
            return addendaKeyList;
        }

    }

}
